import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Tag, Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
// 引入开关组件
type CheckedType = boolean | string | number;

export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'modelName',
    width: 150,
    // onEditRow: true,
    slots: { customRender: 'sourceType' },
  },
  {
    title: '英文名',
    dataIndex: 'EngName',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '描述',
    dataIndex: 'describe',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '工作区',
    dataIndex: 'workArea',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 150,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 150,
  },
  {
    title: '拥有者',
    dataIndex: 'holder',
    width: 150,
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    component: 'Input',
    componentProps: {
      placeholder: '输入关键字搜索',
    },
    colProps: { span: 4 },
  },
];
export const searchFormTwoSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    componentProps: {
      placeholder: '输入关键字搜索主题域名称、英文名',
    },
    colProps: { span: 10 },
  },
];
export const modelFormSchema: any[] = [
  {
    field: 'modelId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'modelName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'name',
    label: '文件名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入登录名',
      },
    ],
  },
  {
    field: 'type',
    label: '文件类型',
    component: 'Input',
    componentProps: {
      defaultValue: '逻辑模型',
      disabled: true,
      readOnly: true,
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const renameFormSchema = [
  {
    field: 'modelName',
    label: '名称',
    required: true,
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
];
export const editFormSchema: any[] = [
  {
    field: 'modelName',
    label: '文件夹名称',
    component: 'Input',
    componentProps: {
      disabled: true,
    },
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入文件夹名称',
      },
    ],
  },
  {
    field: 'conjunctiveModel',
    label: '关联元模型',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '概念元模型',
          value: '概念元模型',
        },
        {
          label: '默认元模型',
          value: '默认元模型',
        },
        {
          label: 'rac元模型',
          value: 'rac元模型',
        },
        {
          label: 'cor元模型',
          value: 'cor元模型',
        },
        {
          label: 'acc元模型',
          value: 'acc元模型',
        },
      ],
      getPopupContainer: () => document.body,
    },
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '元模型只能在一级目录配置',
      },
    ],
  },
]
/**移动*/
export const MoveFormSchema: any[] = [
  {
    field: 'institutionId',
    label: '所属机构',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'institutionName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];

export const importFormSchema: any[] = [
  {
    field: 'fileType',
    label: '导入文件类型',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: 'Erwin(.xml)', value: '1' },
        { label: 'PowerDesigner(.ldm)', value: '2' },
        { label: 'Excel(.xlsx)', value: '3' },
      ],
    },
  },
  {
    field: 'filePath',
    label: '路径',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fileMethods',
    label: '导入文件选择',
    slot: 'fileMethods',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fileRename',
    label: '文件重名',
    component: 'RadioGroup',
    required: true,
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '全部放弃', value: '1' },
        { label: '全部替换', value: '2' },
        { label: '自动重命名', value: '3' },
      ],
    },
  },
];
