import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Tag, Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
import componentProps
  from "@/views/form-design/components/VFormDesign/components/ComponentProps.vue";
// 引入开关组件
type CheckedType = boolean | string | number;

export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'modelName',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '英文名',
    dataIndex: 'EngName',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '描述',
    dataIndex: 'describe',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '工作区',
    dataIndex: 'workArea',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 150,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 150,
  },
  {
    title: '拥有者',
    dataIndex: 'holder',
    width: 150,
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    componentProps: {
      placeholder: '搜索主题域名称、英文名',
    },
    colProps: { span: 7 },
  },
];
export const entityColumns: BasicColumn[] = [
  {
    title: '实体名称',
    dataIndex: 'name',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '实体描述',
    dataIndex: 'txt',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '实体英文名',
    dataIndex: 'engName',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '资产责任人',
    dataIndex: 'person',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '所属部门',
    dataIndex: 'deptName',
    width: 150,
  },
];
export const entityFormSchema: FormSchema[] = [
  {
    field: 'name',
    component: 'Input',
    componentProps: {
      placeholder: '输入实体名称搜索',
    },
    colProps: { span: 4 },
  },
];
export const connectionTable: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '父实体名称',
    dataIndex: 'fatherName',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '父实体属性PK',
    dataIndex: 'fatherPK',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '父端基数',
    dataIndex: 'fatherNum',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '子实体名称',
    dataIndex: 'sonName',
    width: 150,
  },
  {
    title: '子实体属性PK',
    dataIndex: 'sonPK',
    width: 150,
  },
  {
    title: '子端基数',
    dataIndex: 'sonNum',
    width: 150,
  },
];
export const connectionFormSchema: FormSchema[] = [
  {
    field: 'name',
    component: 'Input',
    componentProps: {
      placeholder: '输入关联关系名称搜索',
    },
    colProps: { span: 4 },
  },
];
export const crossTable: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '父逻辑模型名称',
    dataIndex: 'fatherModelName',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '父实体名称',
    dataIndex: 'fatherName',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '父实体属性PK',
    dataIndex: 'fatherPK',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '父端基数',
    dataIndex: 'fatherNum',
    width: 150,
    // onEditRow: true,
  },
  {
    title: '子逻辑模型名称',
    dataIndex: 'sonModelName',
    width: 150,
  },
  {
    title: '子实体名称',
    dataIndex: 'sonName',
    width: 150,
  },
  {
    title: '子实体属性PK',
    dataIndex: 'sonPK',
    width: 150,
  },
  {
    title: '子端基数',
    dataIndex: 'sonNum',
    width: 150,
  },
];
export const crossFormSchema: FormSchema[] = [
  {
    field: 'name',
    component: 'Input',
    componentProps: {
      placeholder: '输入关联关系名称搜索',
    },
    colProps: { span: 4 },
  },
];
export const modelFormSchema: any[] = [
  {
    field: 'modelId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'modelName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'name',
    label: '文件名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入登录名',
      },
    ],
  },
  {
    field: 'type',
    label: '文件类型',
    component: 'Input',
    componentProps: {
      defaultValue: '逻辑模型',
      disabled: true,
      readOnly: true,
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const editFormSchema: any[] = [
  {
    field: 'describe',
    label: '模型描述',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'entityCount',
    label: '实体数量',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'createDate',
    label: '创建时间',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'updateDate',
    label: '更新时间',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'releaseDate',
    label: '发布时间',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'creator',
    label: '创建者',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'publisher',
    label: '发布者',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
  },
];
/**移动*/
export const MoveFormSchema: any[] = [
  {
    field: 'institutionId',
    label: '所属机构',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'institutionName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];
// entityModel
export const EntityModelFormSchema: any[] = [
  {
    field: 'name',
    label: '实体名称',
    component: 'Input',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'txt',
    label: '实体描述',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'engName',
    label: '英文实体名',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'person',
    label: '资产责任人',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'deptName',
    label: '所属部门',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
  },
];
// connectionModel
export const ConnectionModelFormSchema: any[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fatherName',
    label: '父实体名称',
    slot: 'fatherName',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'dw_合约',
          value: 'dw_合约',
        },
        {
          label: 'dw_产品合约行情历史',
          value: 'dw_产品合约行情历史',
        },
      ],
    },
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fatherPK',
    label: '父实体属性PK',
    slot: 'fatherPK',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '合约号',
          value: '合约号',
          entity: 'dw_合约',
        },
        {
          label: '产品合约行情历史号',
          value: '产品合约行情历史号',
          entity: 'dw_产品合约行情历史',
        },
      ],
    },
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fatherNum',
    label: '父端基数',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '1',
          value: '1',
        },
        {
          label: '2',
          value: '2',
        },
        {
          label: '3',
          value: '3',
        },
      ],
    },
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'sonName',
    label: '子实体名称',
    slot: 'sonName',
    component: 'Select',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'sonPK',
    label: '子实体属性PK',
    slot: 'sonPK',
    component: 'Select',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'sonNum',
    label: '子端基数',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '1',
          value: '1',
        },
        {
          label: '2',
          value: '2',
        },
        {
          label: '3',
          value: '3',
        },
      ],
    },
    required: true,
    colProps: { lg: 24, md: 24 },
  },
];
export const turnPhysicalModelFormSchema: any[] = [
  {
    field: 'path',
    label: '存储路径',
    component: 'TreeSelect',
    componentProps: {
      treeData: [
        {
          label: '物理模型',
          value: '物理模型',
          children: [
            {
              label: '物理模型/admin-个人工作区',
              value: '物理模型/admin-个人工作区',
              children: [
                {
                  label: '物理模型/admin-个人工作区/SDM数仓',
                  value: '物理模型/admin-个人工作区/SDM数仓',
                },
              ],
            },
            {
              label: '物理模型/共享工作区',
              value: '物理模型/共享工作区',
              children: [
                {
                  label: '物理模型/共享工作区/SDM数仓',
                  value: '物理模型/共享工作区/SDM数仓',
                },
              ],
            },
          ],
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fileRename',
    label: '文件重名',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '全部放弃', value: '0' },
        { label: '全部替换', value: '1' },
        { label: '自动重命名', value: '2' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'tableInfo',
    label: '表信息',
    slot: 'tableInfo',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'dataSource',
    label: '数据源',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'kk',
          value: 'kk',
        },
        {
          label: 'cc',
          value: 'cc',
        },
        {
          label: 'rr',
          value: 'rr',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'databaseName',
    label: '库名',
    component: 'Input',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'title1',
    label: '表名',
    component: 'Input',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'tableType',
    label: '表类型',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '表',
          value: '表',
        },
        {
          label: '视图',
          value: '视图',
        },
        {
          label: '临时',
          value: '临时',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'tableTxt',
    label: '表注释',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'saveType',
    label: '存储类型',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'ORC',
          value: 'ORC',
        },
        {
          label: 'Parquet',
          value: 'Parquet',
        },
        {
          label: 'CarbonData',
          value: 'CarbonData',
        },
        {
          label: 'Delta Lake',
          value: 'Delta Lake',
        },
        {
          label: 'Avro',
          value: 'Avro',
        },
        {
          label: 'Protobuf',
          value: 'Protobuf',
        },
        {
          label: 'Iceberg',
          value: 'Iceberg',
        },
      ],
    },
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'saveType',
    label: '是否为事务表',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '是',
          value: '是',
        },
        {
          label: '否',
          value: '否',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'title2',
    label: '管理元数据',
    slot: 'tableInfo',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'dept',
    label: '主责部门',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'secretFlag',
    label: '是否加密',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '否', value: '0' },
        { label: '是', value: '1' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'taskName',
    label: '业务定义',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'tableChName',
    label: '表中文名',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'sensitiveFlag',
    label: '是否为敏感信息',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '否', value: '0' },
        { label: '是', value: '1' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const versionModelFormSchema: any[] = [
  {
    field: 'key',
    label: '关联关系名称：',
    component: 'Input',
    componentProps: {
      placeholder: '输入关联关系名称搜索',
    },
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'operator',
    label: '发布人：',
    component: 'Select',
    componentProps: {
      placeholder: '发布人',
    },
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'timeRange',
    label: '发布时间：',
    component: 'RangePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      placeholder: ['开始时间', '结束时间'],
    },
    colProps: { lg: 12, md: 12 },
  },
];
